<?php
/*
Plugin Name: Foliovision Edit Templates
Plugin URI: 
Description: Replace the default page/post edit screen with customised templates and configurable editors. Now with extra Excerpt field and user-specific setting for basic/advanced editing mode.
Version: 0.3.8 
Author: John Godley and changes by Foliovision
Author URI: http://urbangiraffe.com
*/

include (dirname (__FILE__).'/plugin.php');
include (dirname (__FILE__).'/models/editor.php');


class EditTemplates extends ET_Plugin
{
	var $editor;
	var $editors;
	
	/// Change		pBaran		22/02/2008		Foliovision
	// Variable where data about post edit and delete restriction is stored.
	var $bIsRestricted;
	/// End of change		pBaran		22/02/2008
	
	function EditTemplates ()
	{
		$this->editor  = false;
		$this->editors = Editor::get_editors ();
		
		///debug
				
		$this->register_plugin ('edittemplates', __FILE__);
		if (is_admin ())
		{
			if ((strpos ($_SERVER['REQUEST_URI'], 'page.php') && $_GET['action'] == 'edit') || strpos ($_SERVER['REQUEST_URI'], 'page-new.php') !== false)
				$this->editor = 'page';
			else if ((strpos ($_SERVER['REQUEST_URI'], 'post.php') && $_GET['action'] == 'edit') || strpos ($_SERVER['REQUEST_URI'], 'post-new.php') !== false)
				$this->editor = 'post';
			else if (strpos ($_SERVER['REQUEST_URI'], 'comment.php') && $_GET['action'] == 'editcomment')
				$this->editor = 'comment';
			else if ((strpos ($_SERVER['REQUEST_URI'], 'post.php') || strpos ($_SERVER['REQUEST_URI'], 'page.php') || strpos ($_SERVER['REQUEST_URI'], 'page-new.php') || strpos ($_SERVER['REQUEST_URI'], 'post-new.php')) && $_SERVER['REQUEST_METHOD'] == 'POST')
				$this->add_filter ('wp_redirect');
			else if (strpos ($_SERVER['REQUEST_URI'], 'edit-templates.php'))
				$this->add_action ('admin_head');
			/// Change		pBaran		06/02/2008		Foliovision
			// This will remove unused menu pages
			//$this->add_filter ('admin_menu');
			//$this->add_action ('profile_personal_options');
			//$this->add_action ('profile_update');
			/// End of change		pbaran		06/02/2008
			
			/// Change		pBaran		22/02/2008		Foliovision
			// This is post and page administrator restriction handler
			$this->add_filter( 'user_has_cap', 'check_permission', 10, 3 );
			if( is_admin() ){
				$this->add_action( 'dbx_post_sidebar', 'add_post_permission' );
				$this->add_action( 'dbx_page_sidebar', 'add_post_permission' );
				$this->add_action( 'save_post', 'save_post_permission' );
				$this->add_action( 'save_post', 'save_post_short_title' );
				$this->add_action( 'save_post', 'save_post_excerpt2' );
				$this->add_action( 'save_post', 'save_user_fv_edit_templates_advanced' );
				
				/// Addition  mVicenik  28/11/2008  Foliovision
				$this->add_action( 'wp_print_scripts', 'ManageScripts' );
								
				/// pBaran		27/02/2008		Foliovision
				$this->add_action( 'option_posts_per_page', 'edit_post_wysiwyg', 42 );
				
				///	Addition	mVicenik	05/08/2008	Foliovision
				if ( $_POST['action'] == 'post' ) {
				  ///	Addition	mVicenik	15/07/2008	Foliovision
				  $this->add_action( 'save_post', 'redirect_to_new_post' );
				///	end of addition
				}
        ///	end of addition				
			}
			/// End of change		pBaran		22/02/2008
		
			if ($this->editor)
			{
				$this->add_action ('admin_notices', 'inject_manager');
				$this->add_action ('admin_head', 'editor_head');
				$this->add_action ('edit_form_advanced', 'add_template');
				$this->add_action ('edit_page_form', 'add_template');
			}
		}
			
		// Insert editor of choice
		$this->add_filter ('the_editor');
	}
	
	/// Change		pBaran		22/02/2008		Foliovision
	/**
	 *	Checks if user has permissions for editing and deleting posts and pages
	 *
	 *	@param array $aAll Are permissions that current user has
	 *	@param array $aCap Are permissions that needs to be checked
	 *	@param array $aArgs Are actions which will be used with arguments atached to them
	 *
	 *	@return array With changed or unchanged current user permissions, based on if he has rights for edit and delete of specified post or page
	 **/
	function check_permission( $aAll, $aCap, $aArgs ){
		// aArgs[0] stores action that will occur, $aArgs[2] stores Post ID
		/// Addition		pBaran		21/03/2008		Foliovision
		/// this without "!strpos( $_SERVER['REQUEST_URI'], 'edit-comments.php' )" would also prohobit to edit comments.
		if( ( isset( $aArgs[0] ) && isset( $aArgs[2] ) ) && 
			( 'edit_post' == $aArgs[0] || 'delete_post' == $aArgs[0] || 'edit_page' == $aArgs[0] || 'delete_page' == $aArgs[0] ) && 
			( !strpos( $_SERVER['REQUEST_URI'], 'edit-comments.php' ) ) ){
			
			if( $this->is_edit_restricted( intval( $aArgs[2] ) ) && !current_user_can( 'administrator' ) ){
				// $aCap stores permissions that are asked about, so if we want to restrict access, then at least one needs to be false or 0.
				foreach( $aCap as $objKey => $strValue ) $aAll[$strValue] = 0;
			}
		}
		
		return $aAll;
	}
	
	/**
	 *	Adds tiny box on post or page edit if you are administrator
	 *
	 *	@return void
	 **/
	function add_post_permission(){
		if( current_user_can( 'administrator' ) || current_user_can( 'edit_permissions' ) ){
			$iPost = 0;
			if( isset( $_GET['post'] ) ) $iPost = intval( $_GET['post'] );
			$this->bIsRestricted = $this->is_edit_restricted( $iPost );
			
			// this command loads 'view/admin/permissions.php' and creates variable $bIsRestricted with value of $this->bIsRestricted visible by the file
			$this->render_admin( 'permissions', array( 'bIsRestricted' => $this->bIsRestricted ) );
		}
	}
	
	/**
	 *	Checks if post was locked by some admin to be editable and deletable only by admins
	 *
	 *	@param int $iPost Post ID
	 *
	 * @return int/bool 1 if post is locked, false otherwise
	 **/
	function is_edit_restricted( $iPost ){
		global $wpdb;
		
		$objRow = $wpdb->get_row( "SELECT meta_value FROM {$wpdb->postmeta} WHERE post_id = '$iPost' AND meta_key='fp_et_permission'" );
		if( $objRow ) return unserialize( unserialize( $objRow->meta_value ) );
		
		return false;
	}
	
	/**
	 *	Saves into database (post meta data table) if some admin locked post. Meta key is 'fp_et_permission'
	 *
	 *	@param int $iPost Post ID
	 *
	 *	@return void
	 **/
	function save_post_permission( $iPost ){
		if( isset( $_POST['fp_et_permission'] ) ){
			if( !function_exists( 'has_meta' ) ){
				if( file_exists( ABSPATH . 'wp-admin/admin-functions.php' ) ) include( ABSPATH . 'wp-admin/admin-functions.php' );
				elseif( file_exists( ABSPATH . 'wp-admin/includes/post.php' ) ) include( ABSPATH . 'wp-admin/includes/post.php' );
			}
			
			$bPermissionSet = false;
			$bDelete = true;
			if( isset( $_POST['fp_et_admin_edit'] ) ) $bDelete = false;
			
			$aMeta = has_meta( $iPost );
		
			if( count( $aMeta ) > 0 ){
				foreach( $aMeta AS $objItem ){
					if( 'fp_et_permission' == $objItem['meta_key'] ){
						$bPermissionSet = true;
						if( $bDelete ) delete_meta ($objItem['meta_id']);
					}
				}
			}
		
			if( !$bDelete && !$bPermissionSet ){
				$_POST['metakeyinput'] = 'fp_et_permission';
				$_POST['metavalue']    = serialize( true );
		
				add_meta( $iPost );
			}
		}
	}

	function save_post_short_title( $iPost ){
		if( isset( $_POST['fv_short_title'] ) ){
			$strValue = str_replace( "'", '&#39;', stripslashes( $_POST['fv_short_title'] ) );
			$strMeta = get_post_meta( $iPost, 'fv_short_title', true );
				
			///   Modification   22/12/2008  mVicenik Foliovision
			if( !update_post_meta( $iPost, 'fv_short_title', $strValue, $strMeta ) )
				add_post_meta( $iPost, 'fv_short_title', $strValue );
			/*if( !$strMeta && $strValue )
				add_post_meta( $iPost, 'fv_short_title', $strValue );
			elseif( 0 != strcmp( $strValue , $strMeta ) )
				update_post_meta( $iPost, 'fv_short_title', $strValue, $strMeta );*/
			///   End of Modification   22/12/2008  mVicenik Foliovision
		}
	}
	
	///	Addition	mVicenik	15/08/2008	Foliovision
	function save_post_excerpt2( $iPost ){
    if( isset( $_POST['fv_excerpt2'] ) ){
			$strValue = $_POST['fv_excerpt2'];
			$strMeta = get_post_meta( $iPost, 'fv_excerpt2', true );
			
         ///   Modification   22/12/2008  mVicenik Foliovision		
			if( !update_post_meta( $iPost, 'fv_excerpt2', $strValue ) )
				add_post_meta( $iPost, 'fv_excerpt2', $strValue );
			/*if( !$strMeta && $strValue ) {
				add_post_meta( $iPost, 'fv_excerpt2', $strValue );
			}
			elseif( 0 != strcmp( $strValue , $strMeta ) ) {
				update_post_meta( $iPost, 'fv_excerpt2', $strValue );
			}*/
			///   End of Modification   22/12/2008  mVicenik Foliovision
			
		}
	}
	///  End of addition
	
	///	Addition	mVicenik	16/08/2008	Foliovision
	function add_usermeta($user_ID, $key, $value, $unique = false) {
  	global $wpdb, $blog_id;
  
  	$user_ID = (int) $user_ID;
  
  	/*if ( $unique ) {
  		if ( $wpdb->get_var("SELECT meta_key FROM $wpdb->postmeta WHERE meta_key = '$key' AND post_id = '$post_id'") ) {
  			return false;
  		}
  	}*/
  
  	$value = maybe_serialize($value);
  	$value = $wpdb->escape($value);
  
  	$wpdb->query("INSERT INTO $wpdb->usermeta (post_id,meta_key,meta_value) VALUES ('$user_ID','$key','$value')");
  
  	return true;
  } 
	
	function save_user_fv_edit_templates_advanced( $iPost ){
    global $user_ID;
    //die(var_dump($_POST));
    $strMeta = get_usermeta( $user_ID, 'fv_edit_templates_advanced_option', true );
    if( isset( $_POST['fv_edit_templates_advanced_option'] ) ){
			if(!strMeta)
				add_usermeta( $user_ID, 'fv_edit_templates_advanced', $_POST['fv_edit_templates_advanced_option'] );
			else
				update_usermeta( $user_ID, 'fv_edit_templates_advanced', $_POST['fv_edit_templates_advanced_option'], $strMeta );
		}
	}
	///  End of addition
	
	///	Addition	mVicenik	15/07/2008	Foliovision
	/**
	 *	This function is hooked to save_post and redirects to just submited post
	 *
	 *	@param int $iPost Post ID
	 *
	 *	@return void
	 **/
	function redirect_to_new_post($iPost) {
		global $wp_version;
		/// Modification  07/08/2008  mVicenik  Foliovision
		//wp_redirect(get_option('siteurl')."?p=".$iPost);
		wp_redirect(get_permalink($iPost));
		/// End of modification
		if($wp_version<'2.5')
		
			break;
	}
	///	end of addition

	/// Change		pBaran		27/02/2008		Foliovision
	/**
	 *	This function disables rich text editing on posts that are admin editable only
	 *
	 *	@param unknown $in Unknown parameter
	 *
	 *	@return unknown Input parameter
	 **/	 	 	 	 	
	function edit_post_wysiwyg( $in ){
		global $fp_wysiwyg;
		if( isset( $_GET['post'] ) && $this->is_edit_restricted( $_GET['post'] ) ){
			if( isset( $fp_wysiwyg ) ) $fp_wysiwyg->bUseFCK = false;
		}
		return $in;
	}
	/// End of change		pBaran		27/02/2008
	/// End of change		pBaran		22/02/2008
	
	function profile_personal_options ()
	{
		global $current_user;
		$this->render_admin ('userprofile', array ('editors' => $this->editors, 'current' => get_user_option ('custom_editor')));
	}
	
	function profile_update ()
	{
		global $current_user;
		update_user_option ($current_user->id, 'custom_editor', $_POST['custom_editor'], true);
	}
	
	function add_template ()
	{
	?>
	<input type="hidden" name="template" value="<?php echo $_GET['template'] ?>"/>
	<?php	
	}

	/// Change		pBaran		06/02/2008		Foliovision
	// This will get rid of some unused menus
	/*function admin_menu ()
	{
   	add_options_page (__("Editor"), __("Editor"), "edit_plugins", basename (__FILE__), array (&$this, "admin_screen"));
	}
	
	function admin_screen ()
	{
		// Decide what to do
		$url = explode ('&', $_SERVER['REQUEST_URI']);
		$url = $url[0];
		$sub = isset ($_GET['sub']) ? $_GET['sub'] : '';
		$this->render_admin ('submenu', array ('url' => $url, 'sub' => $sub, 'editors' => $this->editors));
		
		if ($sub == '')
			$this->screen_options ();
		else if (class_exists ($_GET['sub']))
		{
			$editor = new $_GET['sub'];
			$editor->register_plugin ('editor', $editor->directory ());
			$editor->options ();
		}
	}
	
	function screen_options ()
	{
		if (isset ($_POST['save']))
		{
			update_option ('editor_default', $_POST['default']);
			$this->render_message ('Your options were saved');
		}
		
		$this->render_admin ('options', array ('default' => get_option ('editor_default'), 'editors' => $this->editors));
	}*/
	/// End of change		pBaran		06/02/2008
	
	function editor_head ()
	{
		$template = 'default';
		if (isset ($_GET['template']) && strlen ($_GET['template']) > 0)
			$template = $_GET['template'];
		
		if (file_exists (TEMPLATEPATH."/view/{$this->plugin_name}/{$this->editor}/head/$template.php"))
			include (TEMPLATEPATH."/view/{$this->plugin_name}/{$this->editor}/head/$template.php");
		else if (file_exists ("{$this->plugin_base}/view/default/{$this->editor}/head/$template.php"))
			include ("{$this->plugin_base}/view/default/{$this->editor}/head/$template.php");
		else
			$this->render_admin ('head_editor');
	}
	
	function admin_head ()
	{
		$this->render_admin ('head_admin');
	}
	
	///  Addition  28/11/2008  mVicenik  Foliovision
	function ManageScripts () {
    if( strpos( $_SERVER['REQUEST_URI'], 'post.php?action=edit&post=' ) || strpos( $_SERVER['REQUEST_URI'], 'post-new.php' ) || strpos( $_SERVER['REQUEST_URI'], 'page.php?action=edit&post=' ) || strpos( $_SERVER['REQUEST_URI'], 'page-new.php' ) ) {
      wp_deregister_script( 'prototype' );
      wp_register_script('prototype', $this->url(). '/js/prototype.js');
      wp_enqueue_script('prototype');
    }
  }
  /// End of addtion
	
	function wp_redirect ($url)
	{
		if (isset ($_POST['submit']) && isset ($_POST['post_ID']))
			return get_permalink (intval ($_POST['post_ID']));
		else if (isset ($_POST['template']) && strlen ($_POST['template']) > 0)
			return $url.'&template='.$_POST['template'];
		return $url;
	}
	
	function inject_manager ()
	{
		if ($_GET['template'] != 'full')
		{
			global $user_ID;
			
			$template = $_GET['template'];
			if ($template == '')
				$template = 'default';
				
			if ($this->editor == 'comment')
			{
				$comment = (int) $_GET['c'];

				if ( ! $comment = get_comment($comment) )
					wp_die(__('Oops, no comment with this ID.').sprintf(' <a href="%s">'.__('Go back').'</a>!', 'javascript:history.go(-1)'));

				if ( !current_user_can('edit_post', $comment->comment_post_ID) )
					wp_die( __('You are not allowed to edit comments on this post.') );

				$comment = get_comment_to_edit($comment);
				$this->render ($this->editor.'/'.$template, array ('comment' => $comment, 'user_ID' => $user_ID));
			}
			else
			{
				$page_ID = $post_ID = $p = (int) $_GET['post'];
				if ($post_ID > 0)
					$post = get_post_to_edit ($page_ID);
				else
					$post = get_default_post_to_edit ();

				if ( 'post' == $post->post_type && $this->editor == 'page')
				{
					wp_redirect("post.php?action=edit&post=$post_ID");
					exit();
				}
				else if ( 'page' == $post->post_type && $this->editor == 'post')
				{
					wp_redirect("page.php?action=edit&post=$post_ID");
					exit();
				}

				/// Change		pBaran		22/02/2008		Foliovision
				// More gentle text on restricted sites
				$strDisplayText = '<div class="wrap"><p>Fragile - Handle with Care.</p> ';
				$strDisplayText .= '<p>For the security of your website this page can only be altered by administrators. ';
				$strDisplayText .= 'Please send your changes to <a href="mailto:programming@foliovision.com">programming(at)foliovision.com</a> ';
				$strDisplayText .= 'or post your changes at webwork.clientsection.com and we will take care of your request right away! ';
				$strDisplayText .= 'Cordial regards, Alec and Peter at Foliovision</p></div> ';
				if ($this->editor == 'page' && !current_user_can ('edit_page', $page_ID) )
					die ( __($strDisplayText) );
			
				if ($this->editor == 'post' && !current_user_can ('edit_post', $post_ID) )
					die ( __($strDisplayText) );
				/// End of change		pBaran		22/02/2008
			
				$messages[1] = __('Post updated');
				$messages[2] = __('Custom field updated');
				$messages[3] = __('Custom field deleted.');
				if (isset($_GET['message']))
					$this->render_message ($message[$_GET['message']]);
		
				if (empty ($post->post_status))
					$post->post_status = 'draft';
			
				$this->render ($this->editor.'/'.$template, array ('page_ID' => $page_ID, 'post_ID' => $post_ID, 'user_ID' => $user_ID, 'post' => $post));
			}
			
			// Add footer and stop
			include (ABSPATH.'wp-admin/admin-footer.php');
			exit;
		}
	}

	function the_editor ($contents)
	{
		preg_match ('@id="(.*?)"@', $contents, $matches);
		
		$editor = $this->get_editor ();
		return $editor->get ($contents, $matches[1]);
	}
	
	function get_editor ($type = '')
	{
		global $current_user;
			
		/// Change		pBaran		06/02/2008		Foliovision
		// We are getting rid of user option menu to select editor. So already saved editor will not get in way
		/*$type = get_user_option ('custom_editor');
		if ($type == '' || $type == 'default')
			$type = get_option ('editor_default');
		
		if ($type == '')
			$type = 'Editor_Default';*/
		/// End of change		pBaran		06/02/2008
		
		$type = 'Editor_Default';

// we wanted to get rid of Xstandard in a big hurry and we don't want any of the other editors turning up apart from the WordPress default editor - we will also get rid of the drop down menu 20070928 - Alec Kinnear with help from Jeremie Jung

		$editor = new $type;
		$editor->register_plugin ('editor', $editor->directory ());
		
		return $editor;
	}
}

// Same as the_editor, but without all the JS junk
function the_real_editor ($content, $id = 'content', $prev_id = 'title')
{
	$rows = get_option ('default_post_edit_rows');
	if (($rows < 3) || ($rows > 100))
		$rows = 12;

	$rows = "rows='$rows'";

	if ( user_can_richedit() )
		add_filter ('the_editor_content', 'wp_richedit_pre');
	
	$the_editor = apply_filters ('the_editor', "<div><textarea class='mceEditor' $rows cols=\"40\" name=\"$id\" tabindex=\"2\" id=\"$id\">%s</textarea></div>\n");
	$the_editor_content = apply_filters ('the_editor_content', $content);

	/// change		pBaran		31/01/2008		Foliovision
	// This line was decoding the html special chracters back to their original characters. When </textarea> occurs inside content, it will then close
	// the edit page textarea causing page to load remaining content onto edit page and not inside edit textarea. Wordpress actually handles this
	// character changes pretty well, so there is probably no need to decode or encode these characters.
	//echo str_replace ('%s', html_entity_decode($the_editor_content), $the_editor);
	echo str_replace ('%s', $the_editor_content, $the_editor);
	/// end of change		pBaran		31/01/2008
}

$pagemanager = new EditTemplates ();

?>